@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class GravatarConfigureSettingsWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit GravatarConfigureSettingsWidgetTest(QObject *parent = nullptr);
-    ~GravatarConfigureSettingsWidgetTest() = default;
+    ~GravatarConfigureSettingsWidgetTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
 };
