@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ GravatarDownloadPixmapDialogTest::GravatarDownloadPixmapDialogTest(QObject *pare
 {
 }
 
-GravatarDownloadPixmapDialogTest::~GravatarDownloadPixmapDialogTest()
-{
-}
+GravatarDownloadPixmapDialogTest::~GravatarDownloadPixmapDialogTest() = default;
 
 void GravatarDownloadPixmapDialogTest::initTestCase()
 {
@@ -29,10 +27,10 @@ void GravatarDownloadPixmapDialogTest::initTestCase()
 void GravatarDownloadPixmapDialogTest::shouldHaveDefaultValue()
 {
     Gravatar::GravatarDownloadPixmapDialog dlg;
-    auto *widget = dlg.findChild<Gravatar::GravatarDownloadPixmapWidget *>(QStringLiteral("gravatarwidget"));
+    auto widget = dlg.findChild<Gravatar::GravatarDownloadPixmapWidget *>(QStringLiteral("gravatarwidget"));
     QVERIFY(widget);
 
-    auto *buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    auto buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
 }
 
